import type { TaskGenerator } from 'ember-concurrency';
import Component from '@ember/component';
/**
 * The AsyncAwareComponent is a low-level component that other components can extend
 * if they need to manage state based on the status of a pending/settled promise.
 *
 * @class AsyncAwareComponent
 */
export default class AsyncAwareComponent<Result = unknown> extends Component {
    /**
     * @argument isPending
     * @type {boolean}
     * @readonly
     */
    readonly isPending: boolean;
    /**
     * A Promise instance that will drive the component's state.
     *
     * @argument promise
     * @type {PromiseLike<unknown>}
     */
    get promise(): PromiseLike<Result> | undefined;
    set promise(value: PromiseLike<Result> | undefined);
    protected _promise?: PromiseLike<Result>;
    protected managePromise(promise: PromiseLike<Result>): TaskGenerator<Result>;
}
