/// <reference types="rsvp" />
import type ModalService from '@nsf-open/ember-ui-foundation/services/modal';
import type BackdropService from '@nsf-open/ember-ui-foundation/services/backdrop';
import Component from '@ember/component';
/**
 * @class UiModalContainer
 */
export default class ModalContainer extends Component {
    readonly modal: ModalService;
    readonly backdrop: BackdropService;
    /**
     * Boolean. Toggles the modal window visible or hidden.
     */
    open: boolean;
    /**
     * String. Naming a modal window allows it to be opened programmatically
     * via the modal service.
     */
    name?: string;
    /**
     * The modal window's heading.
     */
    title?: string;
    /**
     * A generic placeholder for information the modal might need. Same idea as
     * an Ember Controller's model - use it if you need it - though it's getting
     * a different name because "modal.model" is a confusing mouthful.
     *
     * @argument data
     * @type unknown
     */
    data: unknown;
    /**
     * A callback method executed when the modal window begins opening.
     */
    onShow?: () => void;
    /**
     * A callback method executed when the modal window finishes opening - after
     * any transitions are complete.
     */
    onShown?: () => void;
    /**
     * A callback method executed when the modal window begins closing.
     */
    onHide?: () => void;
    /**
     * A callback method executed when the modal window finishes closing - after
     * any transitions are complete.
     */
    onHidden?: () => void;
    /**
     * A callback method executed when the modal window is about to begin closing. This
     * callback has the ability to deny that from occurring if desired by returning a
     * boolean false. In conjunction with `onHideBlocked` this can be used to create
     * some interesting multi-modal workflow patterns.
     */
    onCanHide?: () => void | boolean;
    /**
     * A callback method executed when the modal window is blocked from being opened
     * because another is currently open and refusing to close. In conjunction with
     * `onCanHide` this can be used to create some interesting multi-modal workflow
     * patterns.
     */
    onHideBlocked?: () => void;
    renderInPlace: boolean;
    /**
     * @protected
     */
    dialogId: string;
    /**
     * @protected
     */
    identifier: string;
    /**
     * @protected
     */
    destinationElement: HTMLElement;
    /**
     * @protected
     */
    scrollbarWidth: number;
    /**
     * @protected
     */
    paddingLeft: number | null;
    /**
     * @protected
     */
    paddingRight: number | null;
    /**
     * @protected
     */
    isOpen: boolean;
    /**
     * @protected
     */
    inDom: boolean;
    /**
     * @protected
     */
    showDialog: boolean;
    /**
     * @protected
     */
    bodyOverflow: boolean;
    /**
     * @protected
     */
    originalBodyPad: string | null;
    /**
     * @protected
     */
    resizeListener: EventListener | null;
    /**
     * @protected
     */
    _renderInPlace: boolean;
    init(): void;
    didInsertElement(): void;
    willDestroyElement(): void;
    get dialogElement(): HTMLElement | null;
    calculateScrollbarWidth(): number;
    setDomMarker(): import("rsvp").default.Promise<unknown>;
    removeDomMarker(): import("rsvp").default.Promise<unknown>;
    adjustLayout(): void;
    resetLayout(): void;
    attachResizeListener(): void;
    detachResizeListener(): void;
    handleOpenRequest(identifier: string, data?: unknown, title?: string): import("rsvp").default.Promise<unknown> | globalThis.Promise<void>;
    handleCloseRequest(): import("rsvp").default.Promise<unknown> | globalThis.Promise<void>;
    close(): import("rsvp").default.Promise<unknown> | globalThis.Promise<void>;
    destructionCheck(): boolean;
    openPropertyWatcher(): globalThis.Promise<void>;
    openDialog(): globalThis.Promise<void>;
    closeDialog(): globalThis.Promise<void>;
}
