import type MessageManager from '@nsf-open/ember-ui-foundation/lib/MessageManager';
import type { MessageGroup } from '@nsf-open/ember-ui-foundation/lib/MessageManager';
import Component from '@ember/component';
/**
 * A UiAlertBlock will create a stack of UiAlert components based on the inputs provided
 * to a MessageManager instance.
 *
 * ```handlebars
 *
 * <UiAlertBlock @manager={{this.messages}} />
 * ```
 *
 * ```ts
 * import type { MessageManager } from '@nsf-open/ember-ui-foundation';
 * import { messageManager } from '@nsf-open/ember-ui-foundation';
 * // ...
 * @messageManager()
 * declare readonly messages: MessageManager;
 * ```
 */
export default class UiAlertBlock extends Component {
    static readonly positionalParams: string[];
    /**
     * The MessageManager instance that will be used by this component to generate
     * alert blocks.
     */
    manager: MessageManager;
    /**
     * The data-test-id attribute for this element, if required.
     */
    testId: string;
    get sortedGroups(): MessageGroup[];
    /**
     * @protected
     */
    init(): void;
    /**
     * @protected
     */
    willDestroyElement(): void;
    /**
     * @protected
     */
    onMessageAdded(): void;
}
