import Component from '@ember/component';
import { Dimensions } from '../../constants';
declare type VoidCallback = () => void;
/**
 * The UiCollapse component provides the base mechanics to smoothly collapse/expand a block element.
 */
export default class UiCollapse extends Component {
    /**
     * Toggles whether the element is expanded or collapsed.
     */
    collapsed: boolean;
    /**
     * An optional callback that will run when the element first begins to collapse.
     */
    onHide?: VoidCallback;
    /**
     * An optional callback that will run when the element finishes being collapsed.
     */
    onHidden?: VoidCallback;
    /**
     * An optional callback that will run when the element first begins to expand.
     */
    onShow?: VoidCallback;
    /**
     * An optional callback that will run when the element finishes being expanded.
     */
    onShown?: VoidCallback;
    /**
     * The axis that the collapse/expand will occur on. Can be either "height" or "width".
     */
    collapseDimension: Dimensions;
    /**
     * This can be set to a value > 0 if a custom expanded height/width pixel value is needed.
     */
    expandedSize?: number;
    /**
     * This can be set to a value > 0 if a custom collapsed height/width pixel value is needed.
     */
    collapsedSize: number;
    /**
     * The UiCollapse component sets a `height` or `width` style on the collapsing element
     * in order to provide a destination value for the CSS transition to move to. The inline
     * value is typically removed when no longer needed but if you want it to keep it around
     * for whatever reason you can set this to false.
     */
    resetSizeBetweenTransitions: boolean;
    /**
     * Whether the component is actively undergoing a transition.
     *
     * @protected
     */
    transitioning: boolean;
    /**
     * The calculated size for either width or height that the element will have when
     * the transition is finished. This gets written as an inline style value for the
     *  element.
     *
     * @protected
     */
    transitioningSize?: number;
    /**
     * Most likely, the "transitionend" event will be used to indicate that the
     * collapse/expand has finished. This is a backup timeout if for whatever
     * reason that doesn't happen.
     *
     * @protected
     */
    transitionDuration: number;
    /**
     * An internal flag that will always be the opposite value of collapsed, so, it will
     * be true if the element is expanded and false otherwise. The change occurs on the
     * leading edge of the animation.
     *
     * @protected
     */
    active: boolean;
    protected notTransitioning: boolean;
    protected showContent: boolean;
    get style(): import("@ember/template/-private/handlebars").SafeString | undefined;
    getExpandedSize(action: 'show' | 'hide'): number | undefined;
    show(): globalThis.Promise<void>;
    hide(): globalThis.Promise<void>;
    _onCollapsedChange(): void;
    _updateCollapsedSize(): void;
    _updateExpandedSize(): void;
    init(): void;
}
export {};
