import Component from '@ember/component';
import { DirectionsX } from '../../constants';
/**
 * Provides standardized layout for icon + text components, e.g., buttons, anchors, and
 * their many variants.
 */
export default class UiInlineTextIconLayout extends Component {
    /**
     * The text to display.
     */
    text?: string;
    /**
     * The icon name. Providing the `fa-` prefix is allowed, but not required. Alias for
     * `UiIcon.name`.
     */
    icon?: string;
    /**
     * The placement of the icon, either "left" or "right", relative to the text.
     */
    iconPlacement: DirectionsX;
    /**
     * If true, text will be made screen-reader only at the small breakpoint. This will
     * only apply if an icon has been provided for display.
     */
    responsive: boolean;
    /**
     * Whether to apply the fixed width modifier to the icon. Alias for `UiIcon.fw`.
     */
    fw: boolean;
    /**
     * Alias for `UiIcon.spin`.
     */
    spin: boolean;
    /**
     * For convenience, when set to true the icon will take on the NSF standard "loading/pending"
     * animation.
     */
    pending: boolean;
    /**
     * Tooltip text content. If provided, the standard tooltip icon will be applied. This
     * does not actually generate a UiTooltip instance, just the icon. It's a string instead
     * of a boolean because that is what usually gets thrown around when dealing with tooltips.
     */
    tooltip?: string;
    /**
     * So this is a pretty wild kind of confusing. This allows an implementing component to
     * tell this one whether it should behave as though it has block content for the sake
     * of laying out text. You can see this at work in the template, where it has the ability
     * to falsify (has-block) if it is true.
     *
     * It's used by UiButton to support the icon-only scenario.
     */
    protected doesParentHaveBlockContent: boolean;
    get actualIconPlacement(): DirectionsX;
    get iconClassName(): string | undefined;
    get renderIcon(): boolean;
    get renderIconLeft(): boolean;
    get renderIconRight(): boolean;
    get textClassName(): string;
}
