import Component from '@ember/component';
/**
 * The UiPagerNavbar provides a button group containing first, last, previous, next,
 * and discrete page selectors based on the current state of the parent UiPager.
 */
export default class UiPagerNavbar extends Component {
    /**
     * If true, discrete page navigation options will be shown between the previous and
     * next options. If false, then only the first, previous, next, and last navigators
     * will be shown.
     */
    showPageLinks: boolean;
    /**
     * Toggles between the two label types that a discrete navigation option can have. The
     * default (false) is a simple number denoting the page that the option navigates to. When
     * true, a range will be shown that indicates the individual records on the page. e.g. "1 - 10",
     * "11 - 20", etc.
     */
    showPageLinkRangeLabels: boolean;
    /**
     * The max number of discrete page navigation options to display at one time. Only
     * odd numbers are used, so if an even number is provided here it will have 1 added.
     */
    pageLinkCount: number;
    /**
     * When true, the navbar will hide its discrete page links at the small breakpoint.
     */
    responsive: boolean;
    /**
     * The `aria-label` attribute for the parent nav.
     */
    ariaLabel?: string;
    /**
     * When true, the entire navigation bar will be removed when there are zero pages
     * to navigate.
     */
    hideWhenEmpty: boolean;
    protected disabled: boolean;
    protected currentPage: number;
    protected pageCount: number;
    protected pageSize: number;
    protected recordCount: number;
    protected hasPrevPage: boolean;
    protected hasNextPage: boolean;
    protected goToPage: (pageIdx: number) => void;
    protected goToFirstPage: () => void;
    protected goToPrevPage: () => void;
    protected goToNextPage: () => void;
    protected goToLastPage: () => void;
    protected get disablePrevButtons(): boolean;
    protected get disableNextButtons(): boolean;
    protected get pageNumbers(): {
        idx: number;
        isCurrent: boolean;
        start: number;
        end: number;
        range: string;
    }[] | null;
    protected handleNavigation(keyOrIndex: string | number, event: Event): void;
}
