import UiContextualContainer, { SelectorStrategies, TriggerEvents } from '../-internals/contextual-container/component';
/**
 * The UiPopover component attaches itself to its parent element - typically a
 * button - and will display some text context in a styled flyout when the parent
 * is clicked.
 *
 * The major difference between this an UiTooltip is that the interaction is click
 * driven, and highly preferable if interactive content is to be rendered within
 * a flyout.
 *
 * ```handlebars
 * <UiButton @variant="primary">
 *   Log In
 *   <UiPopover @title="Please Log In to Your Account to Continue">
 *     <div class="form-group">
 *       <label for="username">Username</label>
 *       <input type="text" id="username" class="form-control" />
 *     </div>
 *
 *     <div class="form-group">
 *       <label for="password">Password</label>
 *       <input type="password" id="password" class="form-control" />
 *     </div>
 *
 *     <div class="text-right">
 *       <button type="button" class="btn btn-primary" onclick={{this.login}}>
 *         Login
 *       </button>
 *     </div>
 *   </UiPopover>
 * </UiButton>
 * ```
 */
export default class UiPopoverContextContainer extends UiContextualContainer {
    /**
     * The amount of time, in milliseconds, between the triggering interaction
     * and when the tooltip is displayed.
     */
    delay: number;
    distance: number;
    /** @hidden */
    ariaAttachAs: string;
    /** @hidden */
    closeOnOutsideClick: boolean;
    /** @hidden */
    triggerEvents: TriggerEvents;
    /** @hidden */
    triggerSelector: SelectorStrategies;
    /** @hidden */
    readonly overlayComponent = "ui-popover/element";
    private removeFocus?;
    didInsertElement(): void;
    /** @hidden */
    onShow: () => void;
    /** @hidden */
    onHide: () => void;
}
