import type { Instance, Modifier, Placement, Options } from '@popperjs/core';
import Component from '@ember/component';
/**
 * A wrapper component for the PopperJS placement library.
 *
 * @class UiPopper
 */
export default class UiPopper extends Component {
    /**
     * The anchor that the popped element will be positioned relative to.
     *
     * @argument popperTarget
     * @type {Element|string}
     */
    popperTarget: Element | string;
    /**
     * Enables/disables the instance by creating/destroying it. When disabled,
     * a [data-popper-disabled] attribute will be set on the target element.
     *
     * @argument enabled
     * @type {boolean}
     * @default true
     */
    enabled: boolean;
    /**
     * The `id` of the positioned element. One will be generated if not provided.
     *
     * @argument id
     * @type {string}
     * @default undefined
     */
    id: string;
    /**
     * The `role` attribute of the positioned element.
     *
     * @argument ariaRole
     * @type {string}
     * @default undefined
     */
    ariaRole: string;
    /**
     * Modifiers that will be merged into the PopperJS instance's options hash.
     * https://popper.js.org/docs/v2/modifiers/
     *
     * @argument modifiers
     * @type {Modifier[]}
     * @default undefined
     */
    modifiers?: Modifier<unknown, Record<string, unknown>>[];
    /**
     * Default placement of the positioned element relative to what it is anchoring to.
     *
     * @argument placement
     * @type {string}
     * @default "bottom"
     */
    placement: Placement;
    /**
     * The popper element typically needs to be moved higher in the DOM tree to avoid z-index
     * issues, so this is that "higher" target. This is ignored if `renderInPlace` is true.
     *
     * @argument popperContainer
     * @type {Element|string}
     * @default ".ember-application"
     */
    popperContainer: Element | string;
    /**
     * If `true`, the popper element will not be moved to popperContainer. WARNING: This can cause
     * z-index issues where your popper will be overlapped by DOM elements that aren't nested as
     * deeply in the DOM tree.
     *
     * @argument renderInPlace
     * @type {boolean}
     * @default false
     */
    renderInPlace: boolean;
    /**
     * An optional function executed when popper recalculates layout.
     *
     * @argument onUpdate
     * @type {() => void}
     * @default undefined
     */
    onUpdate?: () => void;
    /**
     * @argument testId
     * @type {string}
     * @default undefined
     * @public
     */
    testId?: string;
    /**
     * The HTML tag that will be rendered as the root element of the popper instance.
     */
    htmlTagName: string;
    /**
     * @private
     */
    readonly disabled: boolean;
    /**
     * @private
     */
    get style(): import("@ember/template/-private/handlebars").SafeString | null;
    /**
     * The actual DOM element that is getting "popped".
     *
     * @private
     */
    get popperElement(): HTMLElement | undefined;
    /**
     * A reference to the Node that this component was a child of before
     * it was possibly moved up in the DOM.
     *
     * @private
     */
    get initialParentNode(): ParentNode | undefined;
    /**
     * @private
     */
    get bailOut(): boolean;
    /**
     * The managing PopperJS instance, so long as `enabled` is true.
     *
     * @private
     */
    popper?: Instance;
    /**
     * A TextNode that is used to access a reference to the parent of
     * this component.
     *
     * @private
     */
    parentFinder?: Text;
    /**
     * A Map of the last known values for the "public" properties that
     * could trigger an update.
     *
     * @private
     */
    valueCache: Map<keyof UiPopper, unknown>;
    /**
     * Check a value against the cache - true if the two are the same, false
     * if not - and optionally update it.
     *
     * @private
     */
    compareToCached(key: keyof UiPopper, value: unknown, update?: boolean): boolean;
    /**
     * The parent DOM node that the popper will be rendered into.
     *
     * @private
     */
    get realPopperContainer(): Element;
    /**
     * Returns the popper Element itself.
     *
     * @private
     */
    get realPopperElement(): HTMLElement | undefined;
    /**
     * Returns the target Element that the popper instance will be anchoring to.
     *
     * @private
     */
    get realPopperTarget(): Element;
    init(): void;
    didInsertElement(): void;
    didUpdateAttrs(): void;
    willDestroyElement(): void;
    schedulePopperUpdate(): void;
    /**
     * Check properties for changes from their last known values.
     *
     * @private
     */
    checkForUpdates(): boolean;
    /**
     * Puts together a set of PopperJS options from the current component configuration.
     *
     * @private
     */
    getPopperOptions(): Options;
    /**
     * Creates, destroys, or updates a Popper instance as required.
     *
     * @private
     */
    updatePopper(): void;
    /**
     * Initializes the PopperJS instance if one does not already exist.
     *
     * @private
     */
    createPopper(): void;
    /**
     * Cleans up the current instance if it exists and resets tracking in the component.
     *
     * @private
     */
    destroyPopper(): void;
}
