import type { FilterRule } from '@nsf-open/ember-ui-foundation/components/ui-filter/component';
import type { ITableColumn } from '@nsf-open/ember-ui-foundation/constants';
import Component from '@ember/component';
/**
 * The UiTable provides a HTML table with support for sorting, filtering, and pagination.
 *
 * @class UiTable
 */
export default class UiTable extends Component {
    records?: unknown[];
    columns?: ITableColumn[];
    filterRules?: FilterRule[];
    filterMethod?: <R>(term: string, records: R[]) => R[];
    /**
     * Text that will be placed within the table's caption element.
     */
    caption?: string;
    /**
     * An array that will be used to populate a menu of options that can
     * be selected to auto-populate the filter text input.
     */
    filters?: {
        label: string;
        value: string;
    }[];
    /**
     * Whether to display a clear button to the right of the filter text input.
     */
    showFilterClearButton: boolean;
    /**
     * The filter text input's placeholder text.
     */
    filterPlaceholder?: string;
    /**
     * Whether filtering of the table's contents is enabled. By default, this
     * includes adding some UI to the top control bar such a text input to
     * provide the filter term.
     */
    filterEnabled: boolean;
    /**
     * Whether the table's content is to be subdivided into multiple pages. This
     * will also enable some UI elements like the page selector.
     */
    pagingEnabled: boolean;
    protected get tableGuid(): string;
    protected get derivedFilterRules(): FilterRule[] | undefined;
}
