import Component from '@ember/component';
/**
 * A single tab option. See UiTabs for implementation details.
 */
export default class UiTabsOption extends Component {
    static readonly positionalParams: string[];
    /**
     * The text to be displayed in the tab. This can also be set as the
     * first positional parameter of the component.
     */
    text: string;
    /**
     * An arbitrary value (primitive or complex, doesn't matter) that goes
     * along with the tab and will be provided via `onChange` callback. This
     * can also be set as the second positional parameter of the component.
     *
     * If not provided, the tab text will be used.
     */
    value: unknown;
    /**
     * If disabled, the tab cannot be interacted with.
     */
    disabled: boolean;
    /**
     * Value of the `data-test-id` attribute of the tab, if needed.
     */
    testId: string;
    /**
     * The `role` of the element. If the parent UiTabs component has a role of
     * `tablist` (the default), then this will always be "presentation".
     */
    role?: string;
    /**
     * Value of the tab's `aria-controls` attribute. If set, it should equal the
     * id the of the `role="tabpanel"` element whose content it makes visible.
     */
    ariaControls?: string;
    /**
     * If true, then the tab's `aria-controls` attribute will be automatically
     * set. Its value will be made available via the `onReady` and `onChange`
     * callbacks and will need to be set as the `id` of the `role="tabpanel"`
     * element whose content it is controlling.
     */
    fullAriaSupport: boolean;
    /**
     * Value of the tab's `id` attribute. If not provided, one will be generated.
     */
    id: string;
    /**
     * Called when the tab has rendered and is ready for interaction.
     */
    onReady?: (value: unknown, tabId: string, controlsId?: string) => void;
    /**
     * Called when the tab is made active.
     */
    onSelect?: (value: unknown, tabId: string, controlsId?: string) => void;
    /**
     * @private
     */
    selectedValue: unknown;
    /**
     * @private
     */
    isTabList: boolean;
    /**
     * @private
     */
    handleTabSelect: (value: unknown, tabId: string, controlsId?: string) => void;
    init(): void;
    didInsertElement(): void;
    /**
     * A thorough check of whether this tab is the active tab.
     */
    protected get isActiveTab(): boolean;
    /**
     * Click event listener for the anchor acting as the tab.
     */
    protected handleAnchorClick(event: Event): void;
}
