import UiContextualContainer, { SelectorStrategies } from '../-internals/contextual-container/component';
/**
 * The UiTooltip component generates an icon that when hovered over with the mouse
 * cursor will display some text context in a styled flyout.
 *
 * ```handlebars
 * <UiTooltip>
 *   This is some description text content.
 * </UiTooltip>
 * ```
 *
 * > __NOTE:__ It is very easy to use this component inappropriately and break accessibility
 * guidelines. Please proceed with caution.
 *
 * Many interactive controls within this library provide built-in support for a tooltip
 * that is correctly accessible, typically via a `tooltip` attribute. You can look at
 * the documentation for UiButton to see an example.
 */
export default class UiTooltipContextContainer extends UiContextualContainer {
    readonly overlayComponent = "ui-tooltip/element";
    /**
     * The icon to be displayed.
     */
    icon: string;
    /**
     * The amount of time, in milliseconds, between the triggering interaction
     * and when the tooltip is displayed.
     */
    delay: number;
    /**
     * The ARIA attribute that will be used to associate the tooltip
     * with the `ariaSelector` element.
     */
    ariaAttachAs: string;
    /**
     * @protected
     */
    triggerSelector: SelectorStrategies;
    /**
     * The `aria-label` attribute of the icon element.
     */
    ariaLabel?: string;
    /**
     * The `aria-hidden` attribute of the icon element.
     */
    ariaHidden?: 'true' | 'false';
    /**
     * The `data-test-id` of both the icon element, and the tooltip container.
     */
    testId?: string;
    get iconClassName(): string;
}
