import Helper from '@ember/component/helper';
/**
 * Provides a way to check whether a value resides within an array. The helper
 * will recompute as needed when items are added to / removed from the array.
 *
 * > __NOTE:__ This does not work properly in Ember < 3.12 and should be avoided.
 *
 * ```ts
 *
 * const locations = ['District of Columbia', 'Maryland', 'Virginia'];
 *
 * ```
 *
 * ```handlebars
 * {{#if (in-array this.locations "Maryland")}}
 *   <p>This content will be rendered</p>
 * {{/if}}
 *
 * {{#if (in-array this.locations "Delaware")}}
 *   <p>This content will not</p>
 * {{/if}}
 * ```
 *
 * ```ts
 *
 * locations.pushObject('Delaware');
 *
 * ```
 *
 * ```handlebars
 * {{#if (in-array this.locations "Delaware")}}
 *   <p>But now it will</p>
 * {{/if}}
 * ```
 */
export default class InArrayHelper extends Helper {
    protected readonly observerKey: keyof this;
    /** @protected */
    targetArray?: unknown[];
    /** @protected */
    listenerAttached: boolean;
    /** @protected */
    compute([array, value]: [unknown[], unknown]): boolean;
    protected updateTargetArray(newArray: unknown[]): void;
}
