import type BackdropService from '@nsf-open/ember-ui-foundation/services/backdrop';
import type ModalContainer from '@nsf-open/ember-ui-foundation/components/-internals/modal-container';
import Evented from '@ember/object/evented';
export declare enum ModalEvents {
    OpenRequest = "openModalRequested",
    CloseRequest = "closeModalRequested"
}
declare const EventedService: Readonly<typeof default> & (new (properties?: object | undefined) => Evented & default) & (new (...args: any[]) => Evented & default);
/**
 * The ModalService exists to provide programmatic control of modal windows in the
 * application. Modal windows with a set name can be opened and closed from here
 * instead of having to set up a boolean flag in your controller/template or component.
 *
 * ```ts
 * import type { ModalService } from '@nsf-open/ember-ui-foundation/services';
 * import { inject as service } from '@ember/service';
 * // ...
 * @service
 * declare readonly modal: ModalService;
 * ```
 */
export default class ModalService extends EventedService {
    protected readonly backdrop: BackdropService;
    /**
     * A reference to the currently opened modal, if there is one.
     */
    protected currentModal: ModalContainer | null;
    /**
     * A reference to the HTMLElement that had focus before the modal was opened.
     * Since modals capture focus, this provides a way to return that focus to where
     * it was when the window first opened.
     */
    protected lastFocused: HTMLElement | null;
    /**
     * Opens a modal window with the given name. The name of a modal is provided via its `name`
     * attribute when defined in a template. Names must be unique.
     *
     * @param identifier The unique name of the modal to be opened.
     * @param [data]     A value that will be yielded back out within the modal body's template as `data`.
     * @param [title]    A title for the modal. Particularly useful if the title needs to be dynamic.
     */
    open(identifier: string, data?: unknown, title?: string): void;
    /**
     * Closes the currently open modal window. Since only one modal can be open at a time no
     * more information is required.
     */
    close(): void;
    /**
     * A convenience method to access the BackdropService `open()` method that will
     * cause the overlay backdrop to be shown.
     */
    showBackdrop(animate?: boolean): import("rsvp").Promise<void>;
    /**
     * A convenience method to access the BackdropService `close()` method that will
     * cause the overlay backdrop to be removed.
     */
    hideBackdrop(animate?: boolean): import("rsvp").Promise<void>;
    /**
     * This will be called by a Modal before it begins to open. If another Modal is already
     * open it will first be given the opportunity to close.
     *
     * @protected
     */
    openRequested(target: ModalContainer, animate?: boolean): Promise<boolean>;
    /**
     * @protected
     */
    closeRequested(target: ModalContainer, animate?: boolean): Promise<void>;
}
declare module '@ember/service' {
    interface Registry {
        modal: ModalService;
    }
}
export {};
