import { KeyCodes } from '@nsf-open/ember-ui-foundation/constants';
/**
 * Describes the possible types of value that can be used to figure out a "starting point" for what
 * should happen with a keystroke.
 */
declare type CurrentElement = undefined | null | string | HTMLElement | ((list: HTMLElement[]) => HTMLElement | undefined);
/**
 *
 */
declare type ElementList = string | HTMLElement[] | NodeListOf<HTMLElement>;
/**
 * The default filter method for HTMLElement that should be ignored for navigation purposes.
 *
 * @param {HTMLElement} element
 *
 * @returns {boolean}
 */
export declare function shouldInclude(element: HTMLElement): boolean;
/**
 * Normalizes a `CurrentElement` into either an HTMLElement or undefined using the following rules:
 *
 * * If `current` is null or undefined       -> undefined
 * * If `current` is an HTMLElement instance -> HTMLElement
 * * If `current` is a string                -> result of document.querySelector(), or undefined
 * * If `current` is a function              -> result of function
 *
 * @param {CurrentElement} current
 * @param {HTMLElement[]}  elements
 *
 * @returns {HTMLElement | undefined}
 */
export declare function getCurrentElement(current: CurrentElement, elements: HTMLElement[]): HTMLElement | undefined;
/**
 * Simply traversing a list of Elements with the keyboard by determining the next HTML Element in a
 * sequence based on the keystroke provided, and the "currently" selected Element.
 */
export default function keyNavigator(current: CurrentElement, list: ElementList, keyCode: KeyCodes | string, { listFilter, wrapAround }?: {
    listFilter?: typeof shouldInclude | undefined;
    wrapAround?: boolean | undefined;
}): HTMLElement | undefined;
export {};
